@@ -6,32 +6,20 @@ import re
 from typing import Generator, List, Optional
 
 from .exceptions import UnableToFindElement
-from .models import ElementSelector, NavigationReference, SelectorGroup
+from .selectors import ElementSelector, NavigationReference, SelectorGroup
 
 
 class AstSelector:
-    """
-    CSS(Ast) Selector:
-
-    Raise = instance type
-    > [el] = direct child
-    .abc = ????
-    #abc = ????
-    [attr is X] = any element where attr is X
-    [attr is None] = any element where attr is X
-    [a=c][b=d] = combine attr selectors
-    """
-
     def __init__(self, query: str, tree: ast.AST) -> None:
         self.tree = tree
         self.query = query
         # TODO: Validate query
 
     def _resolve_query(self) -> List[ElementSelector]:
-        PARENT_RE = r"(\.\.)*"
-        NODE_RE = r"(\$?[A-Z]\w+)*"
-        ATTR_RE = r"(\[[a-zA-Z0-9_= ]+\])*"
-        DRILL_RE = r"(\.\w+)*"
+        PARENT_RE = r"(\.\.)?"
+        DRILL_RE = r"(\.\w+)?"
+        ATTR_RE = r"(\[[a-zA-Z0-9_= ]+\])?"
+        NODE_RE = r"(\$?[A-Z]\w+)?"
 
         reg = re.findall(f"{PARENT_RE}{DRILL_RE}{ATTR_RE}{NODE_RE}", self.query)
         reggroup = [x for x in itertools.chain(*reg) if x]
